package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBeerReviewLike;
import org.apache.ibatis.annotations.Param;

/**
 * 酒评点赞Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
public interface WyBeerReviewLikeMapper 
{
    /**
     * 查询酒评点赞
     * 
     * @param id 酒评点赞主键
     * @return 酒评点赞
     */
    public WyBeerReviewLike selectWyBeerReviewLikeById(Long id);

    /**
     * 查询酒评点赞列表
     * 
     * @param wyBeerReviewLike 酒评点赞
     * @return 酒评点赞集合
     */
    public List<WyBeerReviewLike> selectWyBeerReviewLikeList(WyBeerReviewLike wyBeerReviewLike);

    /**
     * 新增酒评点赞
     * 
     * @param wyBeerReviewLike 酒评点赞
     * @return 结果
     */
    public int insertWyBeerReviewLike(WyBeerReviewLike wyBeerReviewLike);

    /**
     * 修改酒评点赞
     * 
     * @param wyBeerReviewLike 酒评点赞
     * @return 结果
     */
    public int updateWyBeerReviewLike(WyBeerReviewLike wyBeerReviewLike);

    /**
     * 删除酒评点赞
     * 
     * @param id 酒评点赞主键
     * @return 结果
     */
    public int deleteWyBeerReviewLikeById(Long id);
    public int deleteWyBeerReviewLikeByReviewId(Long reviewId);

    /**
     * 批量删除酒评点赞
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBeerReviewLikeByIds(Long[] ids);

    public WyBeerReviewLike selectWyBeerReviewLikeByReviewIdAndCustomerId(@Param("reviewId") Long id,@Param("userId") Long userId);
}
