package com.ruoyi.brewery.controller;

import com.ruoyi.brewery.domain.WyBeer;
import com.ruoyi.brewery.domain.WyBeerReviewLike;
import com.ruoyi.brewery.service.IWyBeerReviewLikeService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 酒评点赞Controller
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
@Api(tags = "酒评点赞")
@RestController
@RequestMapping("/brewery/like")
public class BreweryWyBeerReviewLikeController extends BaseController
{
    @Autowired
    private IWyBeerReviewLikeService wyBeerReviewLikeService;

    /**
     * 查询酒评点赞列表
     */
    @ApiOperation("查询酒评点赞列表")
    @PreAuthorize("@bss.hasPermi('brewery:like:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBeerReviewLike wyBeerReviewLike)
    {
        wyBeerReviewLike.setBreweryId(SecurityUtils.getBreweryLoginUser().getBreweryId());
        startPage();
        List<WyBeerReviewLike> list = wyBeerReviewLikeService.selectWyBeerReviewLikeList(wyBeerReviewLike);
        return getDataTable(list);
    }

    /**
     * 导出酒评点赞列表
     */
    @ApiOperation("导出酒评点赞列表")
    @PreAuthorize("@bss.hasPermi('brewery:like:export')")
    @Log(title = "酒评点赞", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBeerReviewLike wyBeerReviewLike)
    {
        wyBeerReviewLike.setBreweryId(SecurityUtils.getBreweryLoginUser().getBreweryId());
        List<WyBeerReviewLike> list = wyBeerReviewLikeService.selectWyBeerReviewLikeList(wyBeerReviewLike);
        ExcelUtil<WyBeerReviewLike> util = new ExcelUtil<WyBeerReviewLike>(WyBeerReviewLike.class);
        util.exportExcel(response, list, "酒评点赞数据");
    }

    /**
     * 获取酒评点赞详细信息
     */
    @ApiOperation("获取酒评点赞详细信息")
    @PreAuthorize("@bss.hasPermi('brewery:like:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        validate(id);
        return success(wyBeerReviewLikeService.selectWyBeerReviewLikeById(id));
    }

    /**
     * 新增酒评点赞
     */
//    @ApiOperation("新增酒评点赞")
//    @PreAuthorize("@bss.hasPermi('brewery:like:add')")
//    @Log(title = "酒评点赞", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody WyBeerReviewLike wyBeerReviewLike)
//    {
//        return toAjax(wyBeerReviewLikeService.insertWyBeerReviewLike(wyBeerReviewLike));
//    }

    /**
     * 修改酒评点赞
     */
    @ApiOperation("修改酒评点赞")
    @PreAuthorize("@bss.hasPermi('brewery:like:edit')")
    @Log(title = "酒评点赞", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyBeerReviewLike wyBeerReviewLike)
    {
        validate(wyBeerReviewLike.getId());
        return toAjax(wyBeerReviewLikeService.updateWyBeerReviewLike(wyBeerReviewLike));
    }

    /**
     * 删除酒评点赞
     */
    @ApiOperation("删除酒评点赞")
    @PreAuthorize("@bss.hasPermi('brewery:like:remove')")
    @Log(title = "酒评点赞", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id)
    {
        validate(id);
        return toAjax(wyBeerReviewLikeService.deleteWyBeerReviewLikeById(id));
    }

    private void validate(Long id) {
        final WyBeerReviewLike wyBeerReviewLike = wyBeerReviewLikeService.selectWyBeerReviewLikeById(id);
        if (wyBeerReviewLike == null) {
            throw new IllegalArgumentException("酒评点赞不存在");
        }
        if (!SecurityUtils.getBreweryLoginUser().getBreweryId().equals(wyBeerReviewLike.getBreweryId())) {
            throw new IllegalArgumentException("只能操作自己的品牌方的酒评点赞");
        }
    }
}
